@@ -1,7 +1,6 @@
 from typing import Dict, List
 
-
-from solapi.kakao_talk.alim_talk import AlimTalkOptions, AlimTalkMessage
+from solapi.kakao_talk.alim_talk import AlimTalkMessage
 from solapi.message import Message
 from solapi.request import post, default_agent
 from solapi.sms.lms import LMS
@@ -64,4 +63,4 @@ class MessageSender:
                 scheduled_date
             )
         else:
-            return SMS(from_number, to_number, validated_data['text'], scheduled_date)
\ No newline at end of file
+            return SMS(from_number, to_number, validated_data['text'], scheduled_date)
